import { getCurrentUser } from "@nextcloud/auth";
import axios from "@nextcloud/axios";
import { generateUrl } from "@nextcloud/router";
import { spawnDialog } from "@nextcloud/vue/functions/dialog";
import { defineComponent, resolveComponent, createBlock, openBlock, withCtx, createElementVNode, toDisplayString, withModifiers, createVNode, createSlots, createTextVNode } from "vue";
import NcButton from "@nextcloud/vue/components/NcButton";
import NcDialog from "@nextcloud/vue/components/NcDialog";
import NcLoadingIcon from "@nextcloud/vue/components/NcLoadingIcon";
import NcPasswordField from "@nextcloud/vue/components/NcPasswordField";
import { getGettextBuilder } from "@nextcloud/l10n/gettext";
import { getLoggerBuilder } from "@nextcloud/logger";
/*!
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
var PwdConfirmationMode = /* @__PURE__ */ ((PwdConfirmationMode2) => {
  PwdConfirmationMode2["Lax"] = "lax";
  PwdConfirmationMode2["Strict"] = "strict";
  return PwdConfirmationMode2;
})(PwdConfirmationMode || {});
/*!
 * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
const PAGE_LOAD_TIME = Date.now();
const isPasswordConfirmationRequired = (mode) => {
  if (!window.backendAllowsPasswordConfirmation) {
    return false;
  }
  if (mode === PwdConfirmationMode.Strict) {
    return true;
  }
  const serverTimeDiff = PAGE_LOAD_TIME - window.nc_pageLoad * 1e3;
  const timeSinceLogin = Date.now() - (serverTimeDiff + window.nc_lastLogin * 1e3);
  return timeSinceLogin > 30 * 60 * 1e3;
};
/*!
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
const gtBuilder = getGettextBuilder().detectLanguage();
[{ "locale": "ar", "translations": [{ "msgid": "Checking password …", "msgstr": ["يتم التحقق من كلمة المرور..."] }, { "msgid": "Confirm", "msgstr": ["تأكيد"] }, { "msgid": "Confirm your password", "msgstr": ["تأكيد كلمة المرور"] }, { "msgid": "Password", "msgstr": ["كلمة المرور"] }, { "msgid": "Please enter your password", "msgstr": ["يرجى إدخال كلمة المرور الخاصة بك"] }, { "msgid": "This action needs authentication", "msgstr": ["هذا الإجراء يتطلب التحقق من الهوية"] }, { "msgid": "Wrong password", "msgstr": ["كلمة المرور غير صحيحة"] }] }, { "locale": "ast", "translations": [{ "msgid": "Checking password …", "msgstr": ["Comprobando la contraseña…"] }, { "msgid": "Confirm", "msgstr": ["Confirmación"] }, { "msgid": "Confirm your password", "msgstr": ["Confirma la contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Introduz la contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta aición precisa l'autenticación"] }, { "msgid": "Wrong password", "msgstr": ["La contraseña ye incorreuta"] }] }, { "locale": "az", "translations": [{ "msgid": "Confirm", "msgstr": ["Təsdiq edin"] }, { "msgid": "Confirm your password", "msgstr": ["Parolunuzu təsdiq edin"] }, { "msgid": "Password", "msgstr": ["Parol"] }, { "msgid": "Password confirmation dialog already mounted", "msgstr": ["Parolun təsdiqi dialoqu artıq quraşdırılıb"] }, { "msgid": "This action needs authentication", "msgstr": ["Bu əməliyyat autentifikasiya tələb edir"] }, { "msgid": "Wrong password", "msgstr": ["Səhv parol"] }] }, { "locale": "be", "translations": [{ "msgid": "Checking password …", "msgstr": ["Праверка пароля…"] }, { "msgid": "Confirm", "msgstr": ["Пацвердзіць"] }, { "msgid": "Confirm your password", "msgstr": ["Пацвердзіць пароль"] }, { "msgid": "Password", "msgstr": ["Пароль"] }, { "msgid": "Please enter your password", "msgstr": ["Калі ласка, увядзіце ваш пароль"] }, { "msgid": "This action needs authentication", "msgstr": ["Гэта дзеянне патрабуе аўтэнтыфікацыі"] }, { "msgid": "Wrong password", "msgstr": ["Памылковы пароль"] }] }, { "locale": "ca", "translations": [{ "msgid": "Checking password …", "msgstr": ["S'està comprovant la contrasenya …"] }, { "msgid": "Confirm", "msgstr": ["Confirma"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmeu la vostra contrasenya"] }, { "msgid": "Password", "msgstr": ["Contrasenya"] }, { "msgid": "Please enter your password", "msgstr": ["Introduïu la vostra contrasenya"] }, { "msgid": "This action needs authentication", "msgstr": ["Aquesta acció necessita autenticació"] }, { "msgid": "Wrong password", "msgstr": ["Contrasenya incorrecta"] }] }, { "locale": "cs_CZ", "translations": [{ "msgid": "Authentication required", "msgstr": ["Vyžadováno ověření se"] }, { "msgid": "Checking password …", "msgstr": ["Ověřování hesla…"] }, { "msgid": "Confirm", "msgstr": ["Potvrdit"] }, { "msgid": "Password", "msgstr": ["Heslo"] }, { "msgid": "Please enter your password", "msgstr": ["Zadejte heslo"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Tato akce vyžaduje ověření se – potvrďte ji zadáním svého hesla."] }, { "msgid": "Wrong password", "msgstr": ["Nesprávné heslo"] }] }, { "locale": "da", "translations": [{ "msgid": "Checking password …", "msgstr": ["Kontrollerer adgangskoden..."] }, { "msgid": "Confirm", "msgstr": ["Bekræft"] }, { "msgid": "Confirm your password", "msgstr": ["Bekræft din adgangskode"] }, { "msgid": "Password", "msgstr": ["Adgangskode"] }, { "msgid": "Please enter your password", "msgstr": ["Indtast venligst dit kodeord"] }, { "msgid": "This action needs authentication", "msgstr": ["Denne handling kræver godkendelse"] }, { "msgid": "Wrong password", "msgstr": ["forkert Adgangskode"] }] }, { "locale": "de", "translations": [{ "msgid": "Authentication required", "msgstr": ["Authentifizierung erforderlich"] }, { "msgid": "Checking password …", "msgstr": ["Passwort prüfen  …"] }, { "msgid": "Confirm", "msgstr": ["Bestätigen"] }, { "msgid": "Password", "msgstr": ["Passwort"] }, { "msgid": "Please enter your password", "msgstr": ["Bitte gib dein Passwort ein"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Für diese Aktion ist eine Authentifizierung erforderlich. Bitte bestätige diese durch Eingabe deines Passworts."] }, { "msgid": "Wrong password", "msgstr": ["Falsches Passwort"] }] }, { "locale": "de_DE", "translations": [{ "msgid": "Authentication required", "msgstr": ["Authentifizierung erforderlich"] }, { "msgid": "Checking password …", "msgstr": ["Passwort prüfen …"] }, { "msgid": "Confirm", "msgstr": ["Bestätigen"] }, { "msgid": "Password", "msgstr": ["Passwort"] }, { "msgid": "Please enter your password", "msgstr": ["Bitte geben Sie Ihr Passwort ein"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Für diese Aktion ist eine Authentifizierung erforderlich. Bitte bestätigen Sie diese durch Eingabe Ihres Passworts."] }, { "msgid": "Wrong password", "msgstr": ["Falsches Passwort"] }] }, { "locale": "el", "translations": [{ "msgid": "Checking password …", "msgstr": ["Έλεγχος συνθηματικού …"] }, { "msgid": "Confirm", "msgstr": ["Επιβεβαίωση"] }, { "msgid": "Confirm your password", "msgstr": ["Επιβεβαιώστε το συνθηματικό σας"] }, { "msgid": "Password", "msgstr": ["Συνθηματικό"] }, { "msgid": "Please enter your password", "msgstr": ["Παρακαλώ εισάγετε το συνθηματικό σας"] }, { "msgid": "This action needs authentication", "msgstr": ["Αυτή η ενέργεια απαιτεί πιστοποίηση"] }, { "msgid": "Wrong password", "msgstr": ["Λάθος συνθηματικό"] }] }, { "locale": "en_GB", "translations": [{ "msgid": "Checking password …", "msgstr": ["Checking password …"] }, { "msgid": "Confirm", "msgstr": ["Confirm"] }, { "msgid": "Confirm your password", "msgstr": ["Confirm your password"] }, { "msgid": "Password", "msgstr": ["Password"] }, { "msgid": "Please enter your password", "msgstr": ["Please enter your password"] }, { "msgid": "This action needs authentication", "msgstr": ["This action needs authentication"] }, { "msgid": "Wrong password", "msgstr": ["Wrong password"] }] }, { "locale": "es", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando contraseña …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme su contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor, Introduzca su contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contraseña errónea"] }] }, { "locale": "es_AR", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando contraseña …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme su contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor, introduzca su contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contraseña incorrecta"] }] }, { "locale": "es_MX", "translations": [{ "msgid": "Checking password …", "msgstr": ["Verificando contraseña …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirme su contraseña"] }, { "msgid": "Password", "msgstr": ["Contraseña"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor introduzca su contraseña"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contraseña incorrecta"] }] }, { "locale": "et_EE", "translations": [{ "msgid": "Authentication required", "msgstr": ["Autentimine on vajalik"] }, { "msgid": "Checking password …", "msgstr": ["Kontrollin salasõna…"] }, { "msgid": "Confirm", "msgstr": ["Kinnita"] }, { "msgid": "Password", "msgstr": ["Salasõna"] }, { "msgid": "Please enter your password", "msgstr": ["Palun sisesta oma salasõna"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["See tegevus eeldab autentimist, palun tee seda sisestades oma salasõna."] }, { "msgid": "Wrong password", "msgstr": ["Vale salasõna"] }] }, { "locale": "fa", "translations": [{ "msgid": "Checking password …", "msgstr": ["در حال بررسی رمز عبور …"] }, { "msgid": "Confirm", "msgstr": ["تأیید"] }, { "msgid": "Confirm your password", "msgstr": ["رمز عبور خود را تأیید کنید"] }, { "msgid": "Password", "msgstr": ["رمز عبور"] }, { "msgid": "Please enter your password", "msgstr": ["لطفاً رمز عبور خود را وارد کنید"] }, { "msgid": "This action needs authentication", "msgstr": ["این عمل نیاز به احراز هویت دارد"] }, { "msgid": "Wrong password", "msgstr": ["رمز عبور اشتباه است"] }] }, { "locale": "fi_FI", "translations": [{ "msgid": "Checking password …", "msgstr": ["Tarkistetaan salasanaa…"] }, { "msgid": "Confirm", "msgstr": ["Vahvista"] }, { "msgid": "Confirm your password", "msgstr": ["Vahvista salasanasi"] }, { "msgid": "Password", "msgstr": ["Salasana"] }, { "msgid": "Please enter your password", "msgstr": ["Kirjoita salasanasi"] }, { "msgid": "This action needs authentication", "msgstr": ["Tämä toiminto vaatii tunnistautumisen"] }, { "msgid": "Wrong password", "msgstr": ["Väärä salasana"] }] }, { "locale": "fr", "translations": [{ "msgid": "Authentication required", "msgstr": ["Authentification requise"] }, { "msgid": "Checking password …", "msgstr": ["Vérification du mot de passe"] }, { "msgid": "Confirm", "msgstr": ["Confirmer"] }, { "msgid": "Password", "msgstr": ["Mot de passe"] }, { "msgid": "Please enter your password", "msgstr": ["Veuillez saisir votre mot de passe"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Cette action nécessite l'authentification, veuillez confirmer en entrant votre mot de passe."] }, { "msgid": "Wrong password", "msgstr": ["Mot de passe incorrect"] }] }, { "locale": "ga", "translations": [{ "msgid": "Authentication required", "msgstr": ["Fíordheimhniú ag teastáil"] }, { "msgid": "Checking password …", "msgstr": ["Pasfhocal á sheiceáil …"] }, { "msgid": "Confirm", "msgstr": ["Deimhnigh"] }, { "msgid": "Password", "msgstr": ["Pasfhocal"] }, { "msgid": "Please enter your password", "msgstr": ["Cuir isteach do phasfhocal"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Teastaíonn fíordheimhniú don ghníomh seo, deimhnigh é trí do phasfhocal a iontráil."] }, { "msgid": "Wrong password", "msgstr": ["Pasfhocal mícheart"] }] }, { "locale": "gl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Comprobando o contrasinal…"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmar o seu contrasinal"] }, { "msgid": "Password", "msgstr": ["Contrasinal"] }, { "msgid": "Please enter your password", "msgstr": ["Introduza o seu contrasinal"] }, { "msgid": "This action needs authentication", "msgstr": ["Esta acción necesita autenticación"] }, { "msgid": "Wrong password", "msgstr": ["Contrasinal incorrecto"] }] }, { "locale": "hu_HU", "translations": [{ "msgid": "Checking password …", "msgstr": ["Jelszó ellenőrzése…"] }, { "msgid": "Confirm", "msgstr": ["Jóváhagyás"] }, { "msgid": "Confirm your password", "msgstr": ["Hagyja jóvá a jelszavát"] }, { "msgid": "Password", "msgstr": ["Jelszó"] }, { "msgid": "Please enter your password", "msgstr": ["Adja meg a jelszavát"] }, { "msgid": "This action needs authentication", "msgstr": ["A művelethez bejelentkezés szükséges"] }, { "msgid": "Wrong password", "msgstr": ["Hibás jelszó"] }] }, { "locale": "id", "translations": [{ "msgid": "Confirm", "msgstr": ["Konfirmasi"] }, { "msgid": "Confirm your password", "msgstr": ["Konfirmasi kata sandi Anda"] }, { "msgid": "Password", "msgstr": ["Kata sandi"] }, { "msgid": "Password confirmation dialog already mounted", "msgstr": ["Dialog konfirmasi kata sandi sudah dipasang"] }, { "msgid": "This action needs authentication", "msgstr": ["Tindakan ini memerlukan autentikasi"] }, { "msgid": "Wrong password", "msgstr": ["Kata sandi salah"] }] }, { "locale": "is", "translations": [{ "msgid": "Checking password …", "msgstr": ["Athuga lykilorð …"] }, { "msgid": "Confirm", "msgstr": ["Staðfesta"] }, { "msgid": "Confirm your password", "msgstr": ["Staðfestu lykilorðið þitt"] }, { "msgid": "Password", "msgstr": ["Lykilorð"] }, { "msgid": "Please enter your password", "msgstr": ["Settu inn lykilorðið þitt"] }, { "msgid": "This action needs authentication", "msgstr": ["Þessi aðgerð krefst auðkenningar"] }, { "msgid": "Wrong password", "msgstr": ["Rangt lykilorð"] }] }, { "locale": "it", "translations": [{ "msgid": "Checking password …", "msgstr": ["Controllo della password…"] }, { "msgid": "Confirm", "msgstr": ["Conferma"] }, { "msgid": "Confirm your password", "msgstr": ["Conferma la tua password"] }, { "msgid": "Password", "msgstr": ["Password"] }, { "msgid": "Please enter your password", "msgstr": ["Inserisci la tua password"] }, { "msgid": "This action needs authentication", "msgstr": ["Questa azione richiede l'autenticazione"] }, { "msgid": "Wrong password", "msgstr": ["Password errata"] }] }, { "locale": "ja_JP", "translations": [{ "msgid": "Checking password …", "msgstr": ["パスワードのチェック ..."] }, { "msgid": "Confirm", "msgstr": ["確認"] }, { "msgid": "Confirm your password", "msgstr": ["パスワードの確認"] }, { "msgid": "Password", "msgstr": ["パスワード"] }, { "msgid": "Please enter your password", "msgstr": ["パスワードを入力してください"] }, { "msgid": "This action needs authentication", "msgstr": ["この操作には認証が必要です"] }, { "msgid": "Wrong password", "msgstr": ["間違ったパスワード"] }] }, { "locale": "ko", "translations": [{ "msgid": "Checking password …", "msgstr": ["비밀번호 확인 중 ..."] }, { "msgid": "Confirm", "msgstr": ["확인"] }, { "msgid": "Confirm your password", "msgstr": ["비밀번호 확인"] }, { "msgid": "Password", "msgstr": ["비밀번호"] }, { "msgid": "Please enter your password", "msgstr": ["비밀번호를 입력하세요"] }, { "msgid": "This action needs authentication", "msgstr": ["이 동작을 진행하기 위해서는 인증이 필요합니다"] }, { "msgid": "Wrong password", "msgstr": ["잘못된 비밀번호"] }] }, { "locale": "lv", "translations": [{ "msgid": "Authentication required", "msgstr": ["Nepieciešama autentificēšanās"] }, { "msgid": "Checking password …", "msgstr": ["Pārbauda paroli..."] }, { "msgid": "Confirm", "msgstr": ["Apstiprināt"] }, { "msgid": "Password", "msgstr": ["Parole"] }, { "msgid": "Please enter your password", "msgstr": ["Lūgums ievadīt savu paroli"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Šai darbībai ir nepieciešama autentificēšanās. Lūgums to apstiprināt ar savas paroles ievadīšanu."] }, { "msgid": "Wrong password", "msgstr": ["Nepareiza parole"] }] }, { "locale": "ms_MY", "translations": [{ "msgid": "Checking password …", "msgstr": ["Memeriksa kata laluan ..."] }, { "msgid": "Confirm", "msgstr": ["Mengesahkan"] }, { "msgid": "Confirm your password", "msgstr": ["Mengesahkan kata laluan"] }, { "msgid": "Password", "msgstr": ["Kata laluan"] }, { "msgid": "Please enter your password", "msgstr": ["Sila masukkan kata laluan anda"] }, { "msgid": "This action needs authentication", "msgstr": ["Perbuatan ini memerlukan pengesahan"] }, { "msgid": "Wrong password", "msgstr": ["Kata laluan salah"] }] }, { "locale": "nb_NO", "translations": [{ "msgid": "Checking password …", "msgstr": ["Sjekker passord …"] }, { "msgid": "Confirm", "msgstr": ["Bekreft"] }, { "msgid": "Confirm your password", "msgstr": ["Bekreft passordet ditt"] }, { "msgid": "Password", "msgstr": ["Passord"] }, { "msgid": "Please enter your password", "msgstr": ["Vennligst skriv inn passordet ditt"] }, { "msgid": "This action needs authentication", "msgstr": ["Denne handlingen krever autentisering"] }, { "msgid": "Wrong password", "msgstr": ["Feil passord"] }] }, { "locale": "nl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Wachtwoord controleren ..."] }, { "msgid": "Confirm", "msgstr": ["Bevestig"] }, { "msgid": "Confirm your password", "msgstr": ["Bevestig met je wachtwoord"] }, { "msgid": "Password", "msgstr": ["Wachtwoord"] }, { "msgid": "Please enter your password", "msgstr": ["Voer je wachtwoord in"] }, { "msgid": "This action needs authentication", "msgstr": ["Voor deze actie is authenticatie vereist"] }, { "msgid": "Wrong password", "msgstr": ["Wachtwoord verkeerd"] }] }, { "locale": "pl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Sprawdzanie hasła…"] }, { "msgid": "Confirm", "msgstr": ["Potwierdź"] }, { "msgid": "Confirm your password", "msgstr": ["Potwierdź swoje hasło"] }, { "msgid": "Password", "msgstr": ["Hasło"] }, { "msgid": "Please enter your password", "msgstr": ["Wprowadź swoje hasło"] }, { "msgid": "This action needs authentication", "msgstr": ["Wykonanie tej czynności wymaga autoryzacji"] }, { "msgid": "Wrong password", "msgstr": ["Nieprawidłowe hasło"] }] }, { "locale": "pt_BR", "translations": [{ "msgid": "Authentication required", "msgstr": ["Autenticação necessária"] }, { "msgid": "Checking password …", "msgstr": ["Verificando a senha …"] }, { "msgid": "Confirm", "msgstr": ["Confirmar"] }, { "msgid": "Password", "msgstr": ["Senha"] }, { "msgid": "Please enter your password", "msgstr": ["Por favor, insira sua senha"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Esta ação precisa de autenticação. Por favor, confirme-a digitando sua senha."] }, { "msgid": "Wrong password", "msgstr": ["Senha incorreta"] }] }, { "locale": "ro", "translations": [{ "msgid": "Checking password …", "msgstr": ["Se verifică parola ..."] }, { "msgid": "Confirm", "msgstr": ["Confirmare"] }, { "msgid": "Confirm your password", "msgstr": ["Confirmare parolă"] }, { "msgid": "Password", "msgstr": ["Parolă"] }, { "msgid": "Please enter your password", "msgstr": ["Vă rugăm să introduceți parola"] }, { "msgid": "This action needs authentication", "msgstr": ["Această acțiune necesită autentificare"] }, { "msgid": "Wrong password", "msgstr": ["Parolă incorectă"] }] }, { "locale": "ru", "translations": [{ "msgid": "Checking password …", "msgstr": ["Проверка пароля …"] }, { "msgid": "Confirm", "msgstr": ["Подтвердить"] }, { "msgid": "Confirm your password", "msgstr": ["Подтвердите пароль"] }, { "msgid": "Password", "msgstr": ["Пароль"] }, { "msgid": "Please enter your password", "msgstr": ["Пожалуйста, введите свой пароль"] }, { "msgid": "This action needs authentication", "msgstr": ["Для этого действия требуется аутентификация"] }, { "msgid": "Wrong password", "msgstr": ["Неправильный пароль"] }] }, { "locale": "sk_SK", "translations": [{ "msgid": "Checking password …", "msgstr": ["Kontrola hesla..."] }, { "msgid": "Confirm", "msgstr": ["Potvrdiť"] }, { "msgid": "Confirm your password", "msgstr": ["Potvrďte svoje heslo"] }, { "msgid": "Password", "msgstr": ["Heslo"] }, { "msgid": "Please enter your password", "msgstr": ["Zadajte prosím svoje heslo"] }, { "msgid": "This action needs authentication", "msgstr": ["Táto akcia vyžaduje overenie"] }, { "msgid": "Wrong password", "msgstr": ["Nesprávne heslo"] }] }, { "locale": "sl", "translations": [{ "msgid": "Checking password …", "msgstr": ["Poteka preverjanje gesla ..."] }, { "msgid": "Confirm", "msgstr": ["Potrdi"] }, { "msgid": "Confirm your password", "msgstr": ["Potrdi geslo"] }, { "msgid": "Password", "msgstr": ["Geslo"] }, { "msgid": "Please enter your password", "msgstr": ["Vpisati je treba geslo"] }, { "msgid": "This action needs authentication", "msgstr": ["To dejanje zahteva overitev"] }, { "msgid": "Wrong password", "msgstr": ["Napačno geslo"] }] }, { "locale": "sr", "translations": [{ "msgid": "Checking password …", "msgstr": ["Лозинка се проверава…"] }, { "msgid": "Confirm", "msgstr": ["Потврда"] }, { "msgid": "Confirm your password", "msgstr": ["Потврдите своју лозинку"] }, { "msgid": "Password", "msgstr": ["Лозинка"] }, { "msgid": "Please enter your password", "msgstr": ["Молимо вас да унесете своју лозинку"] }, { "msgid": "This action needs authentication", "msgstr": ["За ову акцију је неопходна пријава"] }, { "msgid": "Wrong password", "msgstr": ["Погрешна лозинка"] }] }, { "locale": "sv", "translations": [{ "msgid": "Authentication required", "msgstr": ["Autentisering krävs"] }, { "msgid": "Checking password …", "msgstr": ["Kontrollerar lösenord ..."] }, { "msgid": "Confirm", "msgstr": ["Bekräfta"] }, { "msgid": "Password", "msgstr": ["Lösenord"] }, { "msgid": "Please enter your password", "msgstr": ["Ange ditt lösenord"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Den här åtgärden kräver autentisering, bekräfta genom att ange ditt lösenord."] }, { "msgid": "Wrong password", "msgstr": ["Fel lösenord"] }] }, { "locale": "tr", "translations": [{ "msgid": "Authentication required", "msgstr": ["Kimlik doğrulaması gerekli"] }, { "msgid": "Checking password …", "msgstr": ["Parola dorulanıyor…"] }, { "msgid": "Confirm", "msgstr": ["Parola onayı"] }, { "msgid": "Password", "msgstr": ["Parola"] }, { "msgid": "Please enter your password", "msgstr": ["Lütfen parolanızı yazın"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Bu işlemi yapmak için kimliğinizi doğrulamalısınız. Lütfen parolanızı yazın."] }, { "msgid": "Wrong password", "msgstr": ["Parola geçersiz"] }] }, { "locale": "uk", "translations": [{ "msgid": "Authentication required", "msgstr": ["Потрібна авторизація"] }, { "msgid": "Checking password …", "msgstr": ["Перевірка паролю ..."] }, { "msgid": "Confirm", "msgstr": ["Підтвердити"] }, { "msgid": "Password", "msgstr": ["Пароль"] }, { "msgid": "Please enter your password", "msgstr": ["Зазначте ваш пароль"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Ця дія вимагає авторизацію, зазначте ваш пароль."] }, { "msgid": "Wrong password", "msgstr": ["Помилковий пароль"] }] }, { "locale": "uz", "translations": [{ "msgid": "Authentication required", "msgstr": ["Autentifikatsiya talab qilinadi"] }, { "msgid": "Checking password …", "msgstr": ["Parol tekshirilmoqda…"] }, { "msgid": "Confirm", "msgstr": ["Tasdiqlang"] }, { "msgid": "Password", "msgstr": ["Parol"] }, { "msgid": "Please enter your password", "msgstr": ["Iltimos, parolingizni kiriting"] }, { "msgid": "This action needs authentication, please confirm it by entering your password.", "msgstr": ["Ushbu amaliyot autentifikatsiya talab etadi, parolingizni kiritish orqali buni tasdiqlang."] }, { "msgid": "Wrong password", "msgstr": ["Parol noto'g'ri "] }] }, { "locale": "zh_CN", "translations": [{ "msgid": "Checking password …", "msgstr": ["检查密码 ..."] }, { "msgid": "Confirm", "msgstr": ["确认"] }, { "msgid": "Confirm your password", "msgstr": ["确认你的密码"] }, { "msgid": "Password", "msgstr": ["密码"] }, { "msgid": "Please enter your password", "msgstr": ["请输入您的密码"] }, { "msgid": "This action needs authentication", "msgstr": ["此操作需要身份验证"] }, { "msgid": "Wrong password", "msgstr": ["密码错误"] }] }, { "locale": "zh_HK", "translations": [{ "msgid": "Checking password …", "msgstr": ["正在檢查密碼 …"] }, { "msgid": "Confirm", "msgstr": ["確認"] }, { "msgid": "Confirm your password", "msgstr": ["確認您的密碼"] }, { "msgid": "Password", "msgstr": ["密碼"] }, { "msgid": "Please enter your password", "msgstr": ["請輸入您的密碼"] }, { "msgid": "This action needs authentication", "msgstr": ["此操作需要進行身份驗證"] }, { "msgid": "Wrong password", "msgstr": ["密碼錯誤"] }] }, { "locale": "zh_TW", "translations": [{ "msgid": "Checking password …", "msgstr": ["正在檢查密碼……"] }, { "msgid": "Confirm", "msgstr": ["確認"] }, { "msgid": "Confirm your password", "msgstr": ["確認您的密碼"] }, { "msgid": "Password", "msgstr": ["密碼"] }, { "msgid": "Please enter your password", "msgstr": ["請輸入您的密碼"] }, { "msgid": "This action needs authentication", "msgstr": ["此動作需要驗證"] }, { "msgid": "Wrong password", "msgstr": ["密碼錯誤"] }] }].map(({ locale, translations }) => gtBuilder.addTranslation(locale, {
  headers: {},
  translations: {
    "": Object.fromEntries(translations.map((t2) => [t2.msgid, t2]))
  }
}));
const gt = gtBuilder.build();
gt.ngettext.bind(gt);
const t = gt.gettext.bind(gt);
/*!
 * SPDX-FileCopyrightText: 2025 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: CC0-1.0
 */
const logger = getLoggerBuilder().setApp("@nextcloud/password-confirmation").detectLogLevel().build();
const _sfc_main = defineComponent({
  name: "PasswordDialog",
  components: {
    NcButton,
    NcDialog,
    NcLoadingIcon,
    NcPasswordField
  },
  props: {
    /**
     * Function to call to validate password
     */
    validate: {
      type: Function,
      required: true
    }
  },
  emits: ["close"],
  data() {
    return {
      password: "",
      loading: false,
      showError: false
    };
  },
  computed: {
    helperText() {
      if (this.showError) {
        return this.password === "" ? t("Please enter your password") : t("Wrong password");
      }
      if (this.loading) {
        return t("Checking password …");
      }
      return "";
    }
  },
  mounted() {
    this.focusPasswordField();
  },
  methods: {
    t,
    async confirm() {
      this.showError = false;
      this.loading = true;
      if (this.password === "") {
        this.showError = true;
        return;
      }
      try {
        await this.validate(this.password);
        this.$emit("close", true);
      } catch (error) {
        logger.debug("Exception during password confirmation", { error });
        this.showError = true;
        this.selectPasswordField();
      } finally {
        this.loading = false;
      }
    },
    close(open) {
      if (!open) {
        this.$emit("close", false);
      }
    },
    focusPasswordField() {
      this.$nextTick(() => {
        this.$refs.field.focus();
      });
    },
    selectPasswordField() {
      this.$nextTick(() => {
        this.$refs.field.select();
      });
    }
  }
});
const _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_NcPasswordField = resolveComponent("NcPasswordField");
  const _component_NcLoadingIcon = resolveComponent("NcLoadingIcon");
  const _component_NcButton = resolveComponent("NcButton");
  const _component_NcDialog = resolveComponent("NcDialog");
  return openBlock(), createBlock(_component_NcDialog, {
    name: _ctx.t("Authentication required"),
    "content-classes": "vue-password-confirmation",
    "onUpdate:open": _ctx.close
  }, {
    default: withCtx(() => [
      createElementVNode("p", null, toDisplayString(_ctx.t("This action needs authentication, please confirm it by entering your password.")), 1),
      createElementVNode("form", {
        class: "vue-password-confirmation__form",
        onSubmit: _cache[1] || (_cache[1] = withModifiers((...args) => _ctx.confirm && _ctx.confirm(...args), ["prevent"]))
      }, [
        createVNode(_component_NcPasswordField, {
          ref: "field",
          modelValue: _ctx.password,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => _ctx.password = $event),
          label: _ctx.t("Password"),
          "helper-text": _ctx.helperText,
          error: _ctx.showError,
          required: ""
        }, null, 8, ["modelValue", "label", "helper-text", "error"]),
        createVNode(_component_NcButton, {
          class: "vue-password-confirmation__submit",
          variant: "primary",
          type: "submit",
          disabled: !_ctx.password || _ctx.loading
        }, createSlots({
          default: withCtx(() => [
            createTextVNode(" " + toDisplayString(_ctx.t("Confirm")), 1)
          ]),
          _: 2
        }, [
          _ctx.loading ? {
            name: "icon",
            fn: withCtx(() => [
              createVNode(_component_NcLoadingIcon, { size: 20 })
            ]),
            key: "0"
          } : void 0
        ]), 1032, ["disabled"])
      ], 32)
    ]),
    _: 1
  }, 8, ["name", "onUpdate:open"]);
}
const PasswordDialogVue = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
/*!
 * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: MIT
 */
let INTERCEPTOR_INITIALIZED = false;
const confirmPassword = async () => {
  if (!isPasswordConfirmationRequired(PwdConfirmationMode.Lax)) {
    return Promise.resolve();
  }
  await promptPassword(async (password) => {
    await _confirmPassword(password);
  });
};
async function _confirmPassword(password) {
  logger.debug("Confirming password");
  const url = generateUrl("/login/confirm");
  const { data } = await axios.post(url, { password });
  window.nc_lastLogin = data.lastLogin;
  logger.debug("Password confirmed");
}
async function promptPassword(validate) {
  const result = await spawnDialog(PasswordDialogVue, { validate });
  if (!result) {
    throw new Error("Dialog closed");
  }
}
function addPasswordConfirmationInterceptors(axios2) {
  if (INTERCEPTOR_INITIALIZED) {
    return;
  }
  INTERCEPTOR_INITIALIZED = true;
  let validatePromise;
  axios2.interceptors.request.use(async (config) => {
    if (config.confirmPassword === void 0) {
      return config;
    }
    if (!isPasswordConfirmationRequired(config.confirmPassword)) {
      return config;
    }
    const { promise, resolve } = Promise.withResolvers();
    await promptPassword(async (password) => {
      switch (config.confirmPassword) {
        case PwdConfirmationMode.Lax: {
          await _confirmPassword(password);
          resolve(config);
          return Promise.resolve();
        }
        case PwdConfirmationMode.Strict:
          logger.debug("Adding auth info to the request", { config });
          config.auth = {
            username: getCurrentUser()?.uid ?? "",
            password
          };
          resolve(config);
          validatePromise = Promise.withResolvers();
          return validatePromise.promise;
      }
    });
    return promise;
  });
  axios2.interceptors.response.use(
    (response) => {
      if (response.config.confirmPassword !== PwdConfirmationMode.Strict) {
        return response;
      }
      logger.debug("Password confirmation succeeded", { response });
      window.nc_lastLogin = Date.now() / 1e3;
      validatePromise.resolve();
      return response;
    },
    (error) => {
      if (error.config?.confirmPassword !== PwdConfirmationMode.Strict) {
        throw error;
      }
      logger.debug("Password confirmation failed", { error });
      validatePromise.reject(error);
      if (!(error.response?.status === 403 && error.response.data.message === "Password confirmation is required")) {
        throw error;
      }
      logger.debug("Triggering new request", { error });
      return axios2.request(error.config);
    }
  );
}
export {
  PwdConfirmationMode,
  addPasswordConfirmationInterceptors,
  confirmPassword,
  isPasswordConfirmationRequired
};
//# sourceMappingURL=index.mjs.map
